import 'package:dynamic_widget/dynamic_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder_ing/app_colors.dart';
import 'package:flutter_form_builder_ing/flutter_form_builder_ing.dart';
import 'package:layout_form_builder/datalayer/bean/eform_cache.dart';
import 'package:layout_form_builder/datalayer/constant/eform_properties.dart';
import 'package:line_awesome_flutter/line_awesome_flutter.dart';


class TimePicker extends StatefulWidget {

  static const PROP = [
    EFormProperties.PROP_INPUT_ID,
    EFormProperties.PROP_COMPULSORY,
    EFormProperties.PROP_ON_LOAD_TRIGGERS,
    EFormProperties.PROP_ON_END_EDITING_TRIGGERS,
    EFormProperties.PROP_COMPULSORY_ERR_MSG,
    EFormProperties.PROP_INPUT_LABEL,
    EFormProperties.PROP_INPUT_HINT,
    EFormProperties.PROP_INPUT_ENABLED,
    EFormProperties.PROP_COLLABORATION_GROUP_ID,
    EFormProperties.PROP_DEFAULT_VALUE,
    EFormProperties.PROP_INPUT_VISIBLE,
    EFormProperties.PROP_VISIBLE_ON_PDF,
  ];

  final Map<String, dynamic> fieldProp;
  final ClickListener? listener;

  TimePicker({Key? key, required this.fieldProp, required this.listener}) : super(key: key);
  
  @override
  _TimePickerState createState() => _TimePickerState();
}

class _TimePickerState extends State<TimePicker> {

  @override
  Widget build(BuildContext context) {
    Map<String, dynamic> fp = widget.fieldProp;
    bool enabled = EFormCache.getFormFieldPropBool(context, fp, EFormProperties.PROP_INPUT_ENABLED, defaultValue: true);
    String? label = EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_INPUT_LABEL);
    String? hint = EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_INPUT_HINT);

    final textStyle = EFormCache.getTextStyle();
    final inputDecoration = EFormCache.getInputDecoration(
        label: label ?? "Time",
        hint: hint ?? "Select time",
        suffix: Icon(LineAwesomeIcons.clock, color: AppColors.TextGray, size: 22),
    );

    return Theme(
        data: new ThemeData(
          primaryColor: AppColors.TextGray,
          primaryColorDark: AppColors.TextGray,
        ),
        child: Padding(
          padding: EdgeInsets.only(bottom: 10),
          child: FormBuilderDateTimePicker(
            inputType: InputType.time,
            name: fp[EFormProperties.PROP_INPUT_ID],
            style: textStyle?.textStyle ?? TextStyle(fontSize: 14.0, fontFamily: 'Lato', color: Colors.black),
            validator: (val) {
              return _validate(val);
            },
            onChanged: (str) {
              print("Time picker onChanged: $str");
            },
            enabled: enabled,
            autovalidateMode: AutovalidateMode.disabled,
            decoration: inputDecoration,
          ),
        )
    );
  }

  String? _validate(dynamic value) {
    Map<String, dynamic> fp = widget.fieldProp;
    bool compulsory = EFormCache.getFormFieldPropBool(context, fp, EFormProperties.PROP_COMPULSORY, fromValidator: true, defaultValue: false);
    String compulsoryErrMsg = EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_COMPULSORY_ERR_MSG, fromValidator: true) ?? "";

    bool enabled = EFormCache.getFormFieldPropBool(context, fp, EFormProperties.PROP_INPUT_ENABLED, defaultValue: true);

    if (enabled) {
      String? val = value;
      if (compulsory) {
        if (val == null || val.length == 0) {
          return compulsoryErrMsg;
        }
      }
    }
    return null;
  }
}